@@ -7,19 +7,16 @@ import datetime
 from typing import Dict, List
 
 from Annotations2Sub.Color import Alpha, Color, Rgba
-from Annotations2Sub.internationalization import _
+from Annotations2Sub.tools import _
 
 # 兼容 Python3.6, 3.7
 # Python3.6, 3.7 的 typing 没有 Literal
 try:
     from typing import Literal  # type: ignore
 except ImportError:
+    from Annotations2Sub.tools import DummyLiteral
 
-    class a:
-        def __getitem__(self, b):
-            return b
-
-    exec("Literal = a()")
+    exec("Literal = DummyLiteral()")
 
 
 class Style:
