@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-"""程序入口"""
 
 import _thread
 import argparse
@@ -19,8 +18,6 @@ import defusedxml.ElementTree  # type: ignore
 from Annotations2Sub import version
 from Annotations2Sub.Annotation import Parse
 from Annotations2Sub.Convert import Convert
-from Annotations2Sub.flag import Flags
-from Annotations2Sub.internationalization import _
 from Annotations2Sub.Sub import Sub
 from Annotations2Sub.tools import (
     AnnotationsForArchive,
@@ -29,16 +26,18 @@ from Annotations2Sub.tools import (
     Stderr,
     VideoForInvidious,
     YellowText,
+    _,
+    Flags,
 )
 
 
-def main():
+def run():
     """程序入口"""
     parser = argparse.ArgumentParser(description=_("下载和转换 Youtube 注释"))
     parser.add_argument(
         "queue",
-        type=str,
         nargs="+",
+        type=str,
         metavar=_("文件 或 videoId"),
         help=_("多个需要转换的文件的文件路径或视频ID"),
     )
@@ -93,7 +92,7 @@ def main():
         "-p",
         "--preview-video",
         action="store_true",
-        help=_("预览视频, 需要 mpv(https://mpv.io/) 并指定 invidious 实例"),
+        help=_("预览视频, 需要 mpv(https://mpv.io/)"),
     )
 
     # 与上面同理
@@ -101,11 +100,12 @@ def main():
         "-g",
         "--generate-video",
         action="store_true",
-        help=_("生成视频, 需要 FFmpeg(https://ffmpeg.org/) 并指定 invidious 实例"),
+        help=_("生成视频, 需要 FFmpeg(https://ffmpeg.org/)"),
     )
     parser.add_argument(
         "-i",
         "--invidious-instances",
+        type=str,
         metavar="invidious.domain",
         help=_("指定 invidious 实例(https://redirect.invidious.io/)"),
     )
@@ -211,10 +211,6 @@ def main():
             exit(1)
 
     if args.preview_video or args.generate_video:
-        if args.invidious_instances is None:
-            Stderr(RedText(_("请指定一个 invidious 实例")))
-            Stderr(_("你可以在这里找一个: https://redirect.invidious.io/"))
-            exit(1)
         args.download_for_archive = True
         args.embrace_libass = True
 
